@@ -230,10 +230,10 @@ extern WandExport MagickBooleanType
   MagickMinifyImage(MagickWand *),
   MagickModeImage(MagickWand *,const double),
   MagickModulateImage(MagickWand *,const double,const double,const double),
-  MagickMorphologyImage(MagickWand *,MorphologyMethod,const ssize_t,
-    KernelInfo *),
-  MagickMorphologyImageChannel(MagickWand *,const ChannelType,MorphologyMethod,
-    const ssize_t,KernelInfo *),
+  MagickMorphologyImage(MagickWand *,const MorphologyMethod,const ssize_t,
+    const KernelInfo *),
+  MagickMorphologyImageChannel(MagickWand *,const ChannelType,
+    const MorphologyMethod,const ssize_t,const KernelInfo *),
   MagickMotionBlurImage(MagickWand *,const double,const double,const double),
   MagickMotionBlurImageChannel(MagickWand *,const ChannelType,const double,
     const double,const double),
